Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1306)

Unified Diff: net/cert/cert_database_android.cc

Issue 2363653002: Cleanup unreachable cert adding code (Closed)
Patch Set: Rebased Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/cert/cert_database.cc ('k') | net/cert/cert_database_ios.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/cert/cert_database_android.cc
diff --git a/net/cert/cert_database_android.cc b/net/cert/cert_database_android.cc
index 89a1a44a54bd875e221554b6024b5b7561ea277a..b3a75b09ac365f20c8d4ca729f4f7edb37b0422a 100644
--- a/net/cert/cert_database_android.cc
+++ b/net/cert/cert_database_android.cc
@@ -17,38 +17,18 @@ CertDatabase::CertDatabase()
CertDatabase::~CertDatabase() {}
-int CertDatabase::CheckUserCert(X509Certificate* cert) {
- // NOTE: This method shall never be called on Android.
- //
- // On other platforms, it is only used by the SSLAddCertHandler class
- // to handle veritication and installation of downloaded certificates.
- //
- // On Android, the certificate data is passed directly to the system's
- // CertInstaller activity, which handles verification, naming,
- // installation and UI (for success/failure).
- NOTIMPLEMENTED();
- return ERR_NOT_IMPLEMENTED;
-}
-
-int CertDatabase::AddUserCert(X509Certificate* cert) {
- // This method is only used by the content SSLAddCertHandler which is
- // never used on Android.
- NOTIMPLEMENTED();
- return ERR_NOT_IMPLEMENTED;
-}
-
void CertDatabase::OnAndroidKeyStoreChanged() {
- NotifyObserversOfCertAdded(NULL);
+ NotifyObserversCertDBChanged(NULL);
// Dump the OpenSSLClientKeyStore to drop references to now disconnected
// PrivateKeys stored in the in-memory key store. Note: this assumes that
// every SSLClientAuthCache is dumped as part of notifying
// OnCertAdded. Otherwise client auth decisions will be silently converted to
// no-certificate decisions. See https://crbug.com/382696
OpenSSLClientKeyStore::GetInstance()->Flush();
}
void CertDatabase::OnAndroidKeyChainChanged() {
- observer_list_->Notify(FROM_HERE, &Observer::OnCACertChanged, nullptr);
+ observer_list_->Notify(FROM_HERE, &Observer::OnCertDBChanged, nullptr);
}
} // namespace net
« no previous file with comments | « net/cert/cert_database.cc ('k') | net/cert/cert_database_ios.cc » ('j') | no next file with comments »
@@ -17,38 +17,18 @@ CertDatabase::CertDatabase()
// PrivateKeys stored in the in-memory key store. Note: this assumes that
// every SSLClientAuthCache is dumped as part of notifying
- // OnCertAdded. Otherwise client auth decisions will be silently converted to
- // no-certificate decisions. See https://crbug.com/382696
+ // OnCertDBChanged. Otherwise client auth decisions will be silently converted
+ // to no-certificate decisions. See https://crbug.com/382696
OpenSSLClientKeyStore::GetInstance()->Flush();
}

Powered by Google App Engine
This is Rietveld 408576698